@@ -1,7 +1,8 @@
 import typer
 
-import os
+import os, sys
 pwd = ".".join(__file__.split("/")[:-1])
+sys.path.append(pwd)
 os.system("export PYTHONPATH="+pwd)
 
 import wifi as wifi
